==> setup-wizard-lib-compat-0.1.0-sources.jar: com/android/setupwizardlib/items/ItemViewHolder.java <==
/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.setupwizardlib.items;

import android.support.v7.widget.RecyclerView;
import android.view.View;

import com.android.setupwizardlib.DividerItemDecoration;

class ItemViewHolder extends RecyclerView.ViewHolder
            implements DividerItemDecoration.DividedViewHolder {

    private boolean mIsEnabled;
    private IItem mItem;

    public ItemViewHolder(View itemView) {
        super(itemView);
    }

    @Override
    public boolean isDividerAllowedAbove() {
        return mIsEnabled;
    }

    @Override
    public boolean isDividerAllowedBelow() {
        return mIsEnabled;
    }

    public void setEnabled(boolean isEnabled) {
        mIsEnabled = isEnabled;
        itemView.setClickable(isEnabled);
        itemView.setEnabled(isEnabled);
        itemView.setFocusable(isEnabled);
    }

    public void setItem(IItem item) {
        mItem = item;
    }

    public IItem getItem() {
        return mItem;
    }
}

==> setup-wizard-lib-compat-0.2.0-sources.jar: com/android/setupwizardlib/items/ItemViewHolder.java <==
/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.setupwizardlib.items;

import android.support.v7.widget.RecyclerView;
import android.view.View;

import com.android.setupwizardlib.DividerItemDecoration;

class ItemViewHolder extends RecyclerView.ViewHolder
            implements DividerItemDecoration.DividedViewHolder {

    private boolean mIsEnabled;
    private IItem mItem;

    ItemViewHolder(View itemView) {
        super(itemView);
    }

    @Override
    public boolean isDividerAllowedAbove() {
        return mIsEnabled;
    }

    @Override
    public boolean isDividerAllowedBelow() {
        return mIsEnabled;
    }

    public void setEnabled(boolean isEnabled) {
        mIsEnabled = isEnabled;
        itemView.setClickable(isEnabled);
        itemView.setEnabled(isEnabled);
        itemView.setFocusable(isEnabled);
    }

    public void setItem(IItem item) {
        mItem = item;
    }

    public IItem getItem() {
        return mItem;
    }
}
